# **Issues**

# New Features/ Enhancement
- Implement function to print path [#16](https://github.com/tranlyvu/wiki-link/issues/16)
- Update unit test [#11](https://github.com/tranlyvu/wiki-link/issues/11)
- Enhance loop prevention mechanism [#20](https://github.com/tranlyvu/wiki-link/issues/20)

# Bugs
-
-

# Questions


# Others
-
-